@@ -172,6 +172,9 @@ enum : int {
 // This variable stores all Python types exported by this module.
 extern Shiboken::Module::TypeInitStruct *SbkPySide6_Qt3DExtrasTypeStructs;
 
+// This variable stores all Python types exported by this module in a backwards compatible way with identical indexing.
+[[deprecated]] extern PyTypeObject **SbkPySide6_Qt3DExtrasTypes;
+
 // This variable stores the Python module object exported by this module.
 extern PyObject *SbkPySide6_Qt3DExtrasModuleObject;
 
@@ -181,31 +184,21 @@ extern SbkConverter **SbkPySide6_Qt3DExtrasTypeConverters;
 // Converter indices
 enum [[deprecated]] : int {
     SBK_QT3DEXTRAS_QLIST_INT_IDX                             = 0, // QList<int>
-    SBK_QT3DEXTRAS_QLIST_QT3DCORE_QCOMPONENTPTR_IDX          = 2, // QList<Qt3DCore::QComponent*>
-    SBK_QT3DEXTRAS_QLIST_QT3DEXTRAS_QSPRITESHEETITEMPTR_IDX  = 4, // QList<Qt3DExtras::QSpriteSheetItem*>
-    SBK_QT3DEXTRAS_QLIST_QT3DCORE_QNODEPTR_IDX               = 6, // QList<Qt3DCore::QNode*>
-    SBK_QT3DEXTRAS_QLIST_QT3DCORE_QATTRIBUTEPTR_IDX          = 8, // QList<Qt3DCore::QAttribute*>
-    SBK_QT3DEXTRAS_QLIST_QT3DRENDER_QPARAMETERPTR_IDX        = 10, // QList<Qt3DRender::QParameter*>
-    SBK_QT3DEXTRAS_QLIST_QT3DRENDER_QFILTERKEYPTR_IDX        = 12, // QList<Qt3DRender::QFilterKey*>
-    SBK_QT3DEXTRAS_QLIST_QVARIANT_IDX                        = 14, // QList<QVariant>
-    SBK_QT3DEXTRAS_QLIST_QSTRING_IDX                         = 16, // QList<QString>
-    SBK_QT3DEXTRAS_QMAP_QSTRING_QVARIANT_IDX                 = 18, // QMap<QString,QVariant>
-    SBK_QT3DEXTRAS_CONVERTERS_IDX_COUNT                      = 20,
+    SBK_QT3DEXTRAS_QLIST_QT3DEXTRAS_QSPRITESHEETITEMPTR_IDX  = 1, // QList<Qt3DExtras::QSpriteSheetItem*>
+    SBK_QT3DEXTRAS_QLIST_QVARIANT_IDX                        = 2, // QList<QVariant>
+    SBK_QT3DEXTRAS_QLIST_QSTRING_IDX                         = 3, // QList<QString>
+    SBK_QT3DEXTRAS_QMAP_QSTRING_QVARIANT_IDX                 = 4, // QMap<QString,QVariant>
+    SBK_QT3DEXTRAS_CONVERTERS_IDX_COUNT                      = 5,
 };
 
 // Converter indices
 enum : int {
     SBK_Qt3DExtras_QList_int_IDX                             = 0, // QList<int>
-    SBK_Qt3DExtras_QList_Qt3DCore_QComponentPTR_IDX          = 1, // QList<Qt3DCore::QComponent*>
-    SBK_Qt3DExtras_QList_Qt3DExtras_QSpriteSheetItemPTR_IDX  = 2, // QList<Qt3DExtras::QSpriteSheetItem*>
-    SBK_Qt3DExtras_QList_Qt3DCore_QNodePTR_IDX               = 3, // QList<Qt3DCore::QNode*>
-    SBK_Qt3DExtras_QList_Qt3DCore_QAttributePTR_IDX          = 4, // QList<Qt3DCore::QAttribute*>
-    SBK_Qt3DExtras_QList_Qt3DRender_QParameterPTR_IDX        = 5, // QList<Qt3DRender::QParameter*>
-    SBK_Qt3DExtras_QList_Qt3DRender_QFilterKeyPTR_IDX        = 6, // QList<Qt3DRender::QFilterKey*>
-    SBK_Qt3DExtras_QList_QVariant_IDX                        = 7, // QList<QVariant>
-    SBK_Qt3DExtras_QList_QString_IDX                         = 8, // QList<QString>
-    SBK_Qt3DExtras_QMap_QString_QVariant_IDX                 = 9, // QMap<QString,QVariant>
-    SBK_Qt3DExtras_CONVERTERS_IDX_COUNT                      = 10,
+    SBK_Qt3DExtras_QList_Qt3DExtras_QSpriteSheetItemPTR_IDX  = 1, // QList<Qt3DExtras::QSpriteSheetItem*>
+    SBK_Qt3DExtras_QList_QVariant_IDX                        = 2, // QList<QVariant>
+    SBK_Qt3DExtras_QList_QString_IDX                         = 3, // QList<QString>
+    SBK_Qt3DExtras_QMap_QString_QVariant_IDX                 = 4, // QMap<QString,QVariant>
+    SBK_Qt3DExtras_CONVERTERS_IDX_COUNT                      = 5,
 };
 // Macros for type check
 
